import React, { useEffect } from 'react';
import { View, StyleSheet, Platform,Text,Image } from 'react-native';
import { AMapSdk, MapView, Marker, MapType } from 'react-native-amap3d';
import LinearGradient from 'react-native-linear-gradient';
import { rpx } from '../../utils/rpx';

const MiniMap = () => {
  useEffect(() => {
    AMapSdk.init(
      Platform.select({
        android: "812efd3a950ba3675f928630302c6463",
      })
    );
  }, []);

  const latitude = 26.95500669;
  const longitude = 120.32736769;
  const imageUrl = "https://lxnapi.ccttiot.com/bike/img/static/uRx1B8B8acbquF2TO7Ry";

  return (
    <View style={styles.container}>
      <MapView
        style={styles.map}
        mapType={MapType.Standard}
        zoomControlsEnabled={false}
        initialCameraPosition={{
          target: {
            latitude,
            longitude,
          },
          zoom: 15,
        }}
      >
        <Marker
          position={{
            latitude,
            longitude,
          }}
          icon={{ uri: imageUrl }}
        />
      </MapView>
      <LinearGradient
        colors={[
          'rgba(255,255,255,1)',
          'rgba(255,255,255,1)',
          'rgba(255,255,255,0)',
        ]}
        locations={[0, 0.8, 1]}
        start={{ x: 0, y: 0 }}
        end={{ x: 0, y: 1 }}
        style={styles.mapTop}
        pointerEvents="none"
      >
        <View style={styles.contentContainer}>
          <View style={styles.cont_left}>
            <View style={styles.cont_left_top}>
              <Text style={styles.cont_left_top_txt}>
                上次蓝牙连接位置
              </Text>
              <Text style={styles.updata}>
                更新于 3分钟前
              </Text>
            </View>
            <Text style={styles.cont_left_bot}>
              福建省宁德市福鼎市海滨路200号靠近福鼎第四中学
            </Text>
          </View>
          <View style={styles.cont_right}>
            <Image 
              source={{ uri: 'https://lxnapi.ccttiot.com/bike/img/static/uoWXZvZN5ynoS4CDFM4k' }}  // 替换成你的图标URL
              style={styles.rightIcon}
            />
          </View>
        </View>
      </LinearGradient>
    </View>
  );
};

const styles = StyleSheet.create({
  contentContainer: {
    flexDirection: 'row',
    justifyContent: 'space-between',
    alignItems: 'center',
    padding: rpx(24),
    height: '100%',
  },
  cont_left: {
    flex: 1,
    marginRight: rpx(20),
  },
  cont_left_top: {
    flexDirection: 'row',
    alignItems: 'center',
    marginBottom: rpx(8),
  },
  cont_left_top_txt: {
    fontWeight: '500',
    fontSize: rpx(36),
    color: '#3D3D3D',
    marginRight: rpx(12),
  },
  updata: {
    fontWeight: '400',
    fontSize: rpx(24),
    color: '#808080',
  },
  cont_left_bot: {
    fontWeight: '400',
    fontSize: rpx(24),
    color: '#3D3D3D',
    lineHeight: rpx(32),
  },
  cont_right: {
    width: rpx(48),
    height: rpx(48),
    justifyContent: 'center',
    alignItems: 'center',
  },
  rightIcon: {
    width: rpx(32),
    height: rpx(32),
  },
 
  container: {
    marginTop: rpx(44),
    width: rpx(688),
    height: rpx(380),
    borderRadius: rpx(20),
    overflow: 'hidden',
    position: 'relative',
  },
  mapTop: {
    position: 'absolute',
    left: rpx(0),
    top: rpx(0),
    width: rpx(688),
    height: rpx(112),
    zIndex: 999,
    elevation: 3,
  },
  map: {
    width: '100%',
    height: '100%',
    zIndex: 1,
  },
});

export default MiniMap;